// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent

    property int itemColor: 0

    property bool isEditable: false

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    signal triggered(int newColor);

    //property color tabPanelMarkerColor: "#d9d9d9"
    property color tabPanelMarkerColor: "#639fff"
    property Gradient tabPanelBackgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.5; color: "#dddddd" }
        GradientStop { position: 1.0; color: "white" }
    }

    onItemColorChanged:  {
        detailsPanel.selectTab(itemColor)
        triggered(itemColor)
    }

    Rectangle {
        id: detailsPanel
        anchors.fill: parent

        color: "transparent"

        property int tabWidths: 21
        property int tabHeights: 21
        property int tabCount: 8
        property int tabSpacer: 2

        property int tabStartPos: (detailsPanel.width / 2 - (detailsPanel.tabCount * detailsPanel.tabWidths / 2))

        function selectTab(tab) {
            tab0.isSelected = false
            tab1.isSelected = false
            tab2.isSelected = false
            tab3.isSelected = false
            tab4.isSelected = false
            tab5.isSelected = false
            tab6.isSelected = false
            tab7.isSelected = false

            if (tab === 0) tab0.isSelected = true
            if (tab === 1) tab1.isSelected = true
            if (tab === 2) tab2.isSelected = true
            if (tab === 3) tab3.isSelected = true
            if (tab === 4) tab4.isSelected = true
            if (tab === 5) tab5.isSelected = true
            if (tab === 6) tab6.isSelected = true
            if (tab === 7) tab7.isSelected = true
        }

        AIInspectorTabPanelTab {
            id: tab0
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos

            displayAsColorBlock: true
            colorBlockColor: "transparent"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor
            isSelected: true

            onTriggered: {
                console.debug("transparent triggered.")
                itemColor = 0
            }
        }

        AIInspectorTabPanelTab {
            id: tab1
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + width + detailsPanel.tabSpacer

            displayAsColorBlock: true
            colorBlockColor: "#ffff9c"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#ffff9c triggered.")
                itemColor = 1
            }
        }

        AIInspectorTabPanelTab {
            id: tab2
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + (width + detailsPanel.tabSpacer) *2

            displayAsColorBlock: true
            colorBlockColor: "#ff2b36"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#ff2b36 triggered.")
                itemColor = 2
            }
        }

        AIInspectorTabPanelTab {
            id: tab3
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + (width + detailsPanel.tabSpacer)*3

            displayAsColorBlock: true
            colorBlockColor: "#af7129"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#af7129 triggered.")
                itemColor = 3
            }
        }

        AIInspectorTabPanelTab {
            id: tab4
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + (width + detailsPanel.tabSpacer)*4

            displayAsColorBlock: true
            colorBlockColor: "#b2ff33"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#b2ff33 triggered.")
                itemColor = 4
            }
        }
        AIInspectorTabPanelTab {
            id: tab5
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + (width + detailsPanel.tabSpacer)*5

            displayAsColorBlock: true
            colorBlockColor: "#56b1ff"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#56b1ff triggered.")
                itemColor = 5
            }
        }
        AIInspectorTabPanelTab {
            id: tab6
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + (width + detailsPanel.tabSpacer)*6

            displayAsColorBlock: true
            colorBlockColor: "#ffa2f8"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#ffa2f8 triggered.")
                itemColor = 6
            }
        }
        AIInspectorTabPanelTab {
            id: tab7
            anchors.top: parent.top
            height: detailsPanel.tabHeights
            width: detailsPanel.tabWidths
            anchors.left: parent.left
            anchors.leftMargin: detailsPanel.tabStartPos + (width + detailsPanel.tabSpacer)*7

            displayAsColorBlock: true
            colorBlockColor: "#d37fff"
            colorBlockBorder: "transparent"
            colorBlockSelectedBorder: maincomponent.tabPanelMarkerColor

            onTriggered: {
                console.debug("#d37fff triggered.")
                itemColor = 7
            }
        }
    }
}
